.. pyart-mch documentation master file, created by
   sphinx-quickstart on Wed Oct 19 06:11:15 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyart-mch's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2
   
   io
   aux_io
   core
   bridge
   filters
   correct
   retrieve
   map
   graph
   util
   testing



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

